@@ -54,35 +54,38 @@ colorderv <- function(X, neworder = radixorder(names(X)), pos = c("front","end",
   setAttributes(X[vars], `[[<-`(ax, "names", nam[vars]))
 }
 
-frename <- function(x, ..., cols = NULL) {
+frename <- function(.x, ..., cols = NULL) {
   args <- substitute(c(...))[-1L]
-  nam <- attr(x, "names")
+  nam <- attr(.x, "names")
   namarg <- names(args)
   if(is.null(namarg) || any(namarg == "")) {
     if(!is.function(..1)) stop("... needs to be expressions colname = newname, or a function to apply to the names of columns in cols.")
     FUN <- if(...length() == 1L) ..1 else # could do special case if ...length() == 2L
       function(x) do.call(..1, c(list(x), list(...)[-1L]))
-    if(is.null(cols)) return(`attr<-`(x, "names", FUN(nam)))
-    ind <- cols2int(cols, x, nam, FALSE)
+    if(is.null(cols)) return(`attr<-`(.x, "names", FUN(nam)))
+    ind <- cols2int(cols, .x, nam, FALSE)
     nam[ind] <- FUN(nam[ind])
   } else nam[ckmatch(namarg, nam)] <- as.character(args)
-  return(`attr<-`(x, "names", nam))
+  return(`attr<-`(.x, "names", nam))
 }
 
-# A tiny bit faster than setrename <- function(x, ..., cols = NULL) eval.parent(substitute(x <- frename(x, ..., cols = cols))), but not much...
-setrename <- function(x, ..., cols = NULL) {
+# rnm <- frename # clashes with 2 packages.., rme would work but is inconsistent
+
+# A tiny bit faster than setrename <- function(.x, ..., cols = NULL) eval.parent(substitute(.x <- frename(.x, ..., cols = cols))), but not much...
+setrename <- function(.x, ..., cols = NULL) {
   args <- substitute(c(...))[-1L]
-  nam <- attr(x, "names")
+  nam <- attr(.x, "names")
   namarg <- names(args)
   if(is.null(namarg) || any(namarg == "")) {
     if(!is.function(..1)) stop("... needs to be expressions colname = newname, or a function to apply to the names of columns in cols.")
     FUN <- if(...length() == 1L) ..1 else # could do special case if ...length() == 2L
       function(x) do.call(..1, c(list(x), list(...)[-1L]))
     if(is.null(cols)) nam <- FUN(nam) else {
-      ind <- cols2int(cols, x, nam, FALSE)
+      ind <- cols2int(cols, .x, nam, FALSE)
       nam[ind] <- FUN(nam[ind])
     }
   } else nam[ckmatch(namarg, nam)] <- as.character(args)
-  eval.parent(substitute(attr(x, "names") <- nam))
+  eval.parent(substitute(attr(.x, "names") <- nam))
 }
 
+# setrnm <- setrename
